@@ -19,8 +19,7 @@ sub new {
 
 sub build_requires {
     return +{
-	'Test::More'	=> 0.40,
-##	'Test::More'	=> 0.88,	# Because of done_testing().
+	'Test::More'	=> 0.88,	# Because of done_testing().
     };
 }
 
@@ -148,7 +147,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2011 by Thomas R. Wyant, III
+Copyright (C) 2010-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
